@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' project.
- * Copyright (c) 2013-2021, Marek Gagolewski <https://www.gagolewski.com>
+ * Copyright (c) 2013-2024, Marek Gagolewski <https://www.gagolewski.com/>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,6 +31,7 @@
 
 
 #include "stri_stringi.h"
+#include "stri_container_utf8.h"
 #include "stri_container_utf16.h"
 #include "stri_container_regex.h"
 
@@ -69,9 +70,9 @@
  */
 SEXP stri__replace_allfirstlast_regex(SEXP str, SEXP pattern, SEXP replacement, SEXP opts_regex, int type)
 {
-    PROTECT(str = stri_prepare_arg_string(str, "str"));
-    PROTECT(replacement = stri_prepare_arg_string(replacement, "replacement"));
-    PROTECT(pattern = stri_prepare_arg_string(pattern, "pattern"));
+    PROTECT(str = stri__prepare_arg_string(str, "str"));
+    PROTECT(replacement = stri__prepare_arg_string(replacement, "replacement"));
+    PROTECT(pattern = stri__prepare_arg_string(pattern, "pattern"));
     StriRegexMatcherOptions pattern_opts =
         StriContainerRegexPattern::getRegexOptions(opts_regex);
 
@@ -169,7 +170,7 @@ SEXP stri__replace_allfirstlast_regex(SEXP str, SEXP pattern, SEXP replacement,
  */
 SEXP stri__replace_all_regex_no_vectorize_all(SEXP str, SEXP pattern, SEXP replacement, SEXP opts_regex)
 {   // version beta
-    PROTECT(str          = stri_prepare_arg_string(str, "str"));
+    PROTECT(str          = stri__prepare_arg_string(str, "str"));
 
     // if str_n is 0, then return an empty vector
     R_len_t str_n = LENGTH(str);
@@ -178,8 +179,8 @@ SEXP stri__replace_all_regex_no_vectorize_all(SEXP str, SEXP pattern, SEXP repla
         return stri__vector_empty_strings(0);
     }
 
-    PROTECT(pattern      = stri_prepare_arg_string(pattern, "pattern"));
-    PROTECT(replacement  = stri_prepare_arg_string(replacement, "replacement"));
+    PROTECT(pattern      = stri__prepare_arg_string(pattern, "pattern"));
+    PROTECT(replacement  = stri__prepare_arg_string(replacement, "replacement"));
     StriRegexMatcherOptions pattern_opts =
         StriContainerRegexPattern::getRegexOptions(opts_regex);
 
@@ -247,8 +248,8 @@ SEXP stri__replace_all_regex_no_vectorize_all(SEXP str, SEXP pattern, SEXP repla
 
 // version alpha == to slow == too many toutf16 conversions
 //{
-//   PROTECT(pattern      = stri_prepare_arg_string(pattern, "pattern"));
-//   PROTECT(replacement  = stri_prepare_arg_string(replacement, "replacement"));
+//   PROTECT(pattern      = stri__prepare_arg_string(pattern, "pattern"));
+//   PROTECT(replacement  = stri__prepare_arg_string(replacement, "replacement"));
 //
 //   R_len_t pattern_n = LENGTH(pattern);
 //   R_len_t replacement_n = LENGTH(replacement);
@@ -331,3 +332,106 @@ SEXP stri_replace_last_regex(SEXP str, SEXP pattern, SEXP replacement, SEXP opts
 {
     return stri__replace_allfirstlast_regex(str, pattern, replacement, opts_regex, -1);
 }
+
+
+
+
+
+
+/**
+ * Converts a single gsub to stri_replace replacement string
+ *
+ * @param x
+ * @return a single R string
+ */
+SEXP stri__replace_rstr_1(const String8& _x)
+{
+    STRI_ASSERT(!_x.isNA());
+    R_len_t n = _x.length();
+    const char* x = _x.c_str();
+
+    std::string buf;
+    buf.reserve(n+1);  // whatever
+
+    R_len_t i=0;
+    while (i < n) {
+        if (x[i] == '$')
+            buf.append("\\$");
+        else if (x[i] == '\\') {
+            i++;
+            if (i >= n)  {
+                // dangling backslash
+                //throw StriException(MSG__INVALID_FORMAT_SPECIFIER, "");
+                // gsub compatibility:
+                break;
+            }
+
+            if (x[i] == '$')
+                buf.append("\\$");
+            else if (x[i] == '\\')
+                buf.append("\\\\");
+            else if (x[i] >= '1' && x[i] <= '9') {  // \\0 not supported
+                buf.push_back('$');
+                buf.push_back(x[i]);
+                if (i+1 < n && (x[i+1] >= '0' && x[i+1] <= '9'))
+                    buf.push_back('\\');
+            }
+            else
+                buf.push_back(x[i]);
+        }
+        else
+            buf.push_back(x[i]);
+
+        i++;
+    }
+
+    return Rf_mkCharLenCE(buf.data(), buf.size(), CE_UTF8);
+}
+
+
+
+/**
+ * Convert \1 to $1 and $ to \$ and \a to a
+ * (gsub vs. stri_replace replacement strings)
+ *
+ * @param x character vector
+ *
+ * @return character vector
+ *
+ * @version 1.6.4 (Marek Gagolewski, 2021-06-16)
+ */
+SEXP stri_replace_rstr(SEXP x)
+{
+    PROTECT(x = stri__prepare_arg_string(x, "x"));
+    R_len_t vectorize_length = LENGTH(x);
+    if (vectorize_length <= 0) {
+        UNPROTECT(1);
+        return Rf_allocVector(STRSXP, 0);
+    }
+
+    STRI__ERROR_HANDLER_BEGIN(1)
+    StriContainerUTF8 x_cont(x, vectorize_length);
+
+    SEXP ret;
+    STRI__PROTECT(ret = Rf_allocVector(STRSXP, vectorize_length));
+
+    for (
+        R_len_t i = x_cont.vectorize_init();
+        i != x_cont.vectorize_end();
+        i = x_cont.vectorize_next(i)
+    ) {
+        if (x_cont.isNA(i)) {
+            SET_STRING_ELT(ret, i, NA_STRING);
+            continue;
+        }
+
+        SEXP out;
+        STRI__PROTECT(out = stri__replace_rstr_1(x_cont.get(i)));
+        SET_STRING_ELT(ret, i, out);
+        STRI__UNPROTECT(1);
+    }
+
+    STRI__UNPROTECT_ALL
+    return ret;
+    STRI__ERROR_HANDLER_END(;/* nothing special to be done on error */)
+}
